"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.PublicAttachmentService = void 0;
const axios_1 = __importDefault(require("axios"));
const content_disposition_1 = __importDefault(require("content-disposition"));
const mime_types_1 = __importDefault(require("mime-types"));
const exceptions_1 = require("./exceptions");
class PublicAttachmentService {
    getFilenameFromUrl(publicUrl, contentType) {
        var _a, _b;
        const filename = (_b = (_a = publicUrl.split('/')) === null || _a === void 0 ? void 0 : _a.pop()) === null || _b === void 0 ? void 0 : _b.split('#')[0].split('?')[0];
        if (!filename)
            return undefined;
        const splittedName = filename.split('.');
        if (splittedName.length >= 2)
            return filename;
        if (contentType)
            return `${filename}.${mime_types_1.default.extension(contentType)}`;
        return undefined;
    }
    getFilenameFromContentDisposition(contentDisposition) {
        const { parameters: { filename }, } = content_disposition_1.default.parse(contentDisposition);
        return filename;
    }
    async getAttachment(publicUrl) {
        const response = await axios_1.default.get(publicUrl, { responseType: 'arraybuffer' });
        const contentDisposition = response.headers['content-disposition'];
        const contentType = response.headers['content-type'];
        let filename;
        if (contentDisposition)
            filename = this.getFilenameFromContentDisposition(contentDisposition);
        if (!filename)
            filename = this.getFilenameFromUrl(publicUrl, contentType);
        if (!filename)
            throw new exceptions_1.UnableToGetFilenameException();
        return {
            filename,
            content: Buffer.from(response.data, 'binary'),
        };
    }
}
exports.PublicAttachmentService = PublicAttachmentService;
//# sourceMappingURL=publicAttachment.service.js.map