"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const common_1 = require("@nestjs/common");
const testing_1 = require("@nestjs/testing");
const delay = (ms) => new Promise((resolve) => setTimeout(resolve, ms));
const cacheMaxCapacity = 5;
const defaultTtlInMs = 500;
describe('nest in-memory cache manager', () => {
    let cache = null;
    beforeEach(async () => {
        const moduleRef = await testing_1.Test.createTestingModule({
            imports: [
                common_1.CacheModule.register({
                    ttl: defaultTtlInMs,
                    max: cacheMaxCapacity,
                }),
            ],
        }).compile();
        cache = await moduleRef.get(common_1.CACHE_MANAGER);
    });
    it('default ttl', async () => {
        cache === null || cache === void 0 ? void 0 : cache.set('cacheKey', 'test');
        await delay(300);
        expect(await (cache === null || cache === void 0 ? void 0 : cache.get('cacheKey'))).toEqual('test');
        await delay(400);
        expect(await (cache === null || cache === void 0 ? void 0 : cache.get('cacheKey'))).toBeUndefined();
    });
    it('ttl on cache item', async () => {
        cache === null || cache === void 0 ? void 0 : cache.set('cacheKey', 'test', 1000);
        await delay(800);
        expect(await (cache === null || cache === void 0 ? void 0 : cache.get('cacheKey'))).toEqual('test');
        await delay(400);
        expect(await (cache === null || cache === void 0 ? void 0 : cache.get('cacheKey'))).toBeUndefined();
    });
    it('cache max capacity', async () => {
        const testKeysCount = 20;
        for (let i = 0; i < testKeysCount; i++) {
            cache === null || cache === void 0 ? void 0 : cache.set(`cacheKey${i}`, `test${i}`);
        }
        for (let i = 0; i < testKeysCount; i++) {
            const itemFromCache = await (cache === null || cache === void 0 ? void 0 : cache.get(`cacheKey${i}`));
            if (i < testKeysCount - cacheMaxCapacity)
                expect(itemFromCache).toBeUndefined();
            else
                expect(itemFromCache).toEqual(`test${i}`);
        }
    });
});
//# sourceMappingURL=cacheManager.integ-spec.js.map