"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CmsCachedService = exports.WEBHOOKS_CACHE_KEY = exports.CARRIER_CACHE_KEY = exports.CUSTOMER_CARRIER_CREDENTIALS_CACHE_KEY = void 0;
exports.CUSTOMER_CARRIER_CREDENTIALS_CACHE_KEY = 'CMS_CUSTOMER_CARRIER_CREDENTIALS';
exports.CARRIER_CACHE_KEY = 'CMS_CARRIER';
exports.WEBHOOKS_CACHE_KEY = 'CMS_WEBHOOKS';
class CmsCachedService {
    constructor(cmsService, cacheService, cacheTtlInMs) {
        this.cmsService = cmsService;
        this.cacheService = cacheService;
        this.cacheTtlInMs = cacheTtlInMs;
        this.cacheTtlInMs = cacheTtlInMs !== null && cacheTtlInMs !== void 0 ? cacheTtlInMs : 10 * 60 * 1000;
    }
    generateCustomerCarrierCacheKey(customerId, carrierId) {
        return `${exports.CUSTOMER_CARRIER_CREDENTIALS_CACHE_KEY}_${customerId}_${carrierId}`;
    }
    generateCarrierCacheKey(carrierId) {
        return `${exports.CARRIER_CACHE_KEY}_${carrierId}`;
    }
    async getCustomerCarrierCredentials(customerId, carrier) {
        const query = () => this.cmsService.getCustomerCarrierCredentials(customerId, carrier);
        return this.cacheService.getOrSetIfNotFound(this.generateCustomerCarrierCacheKey(customerId, carrier), query, this.cacheTtlInMs);
    }
    async getCarrier(carrierId) {
        const query = () => this.cmsService.getCarrier(carrierId);
        return this.cacheService.getOrSetIfNotFound(this.generateCarrierCacheKey(carrierId), query, this.cacheTtlInMs);
    }
    async getExternalSystemsWebhooks() {
        const query = () => this.cmsService.getExternalSystemsWebhooks();
        return this.cacheService.getOrSetIfNotFound(exports.WEBHOOKS_CACHE_KEY, query, this.cacheTtlInMs);
    }
}
exports.CmsCachedService = CmsCachedService;
//# sourceMappingURL=cmsCached.service.js.map